@@ -317,6 +317,12 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[CheckItem{offs: 0, cond: &CC::Or(&CC::Str(b"CDA2"), &CC::Str(b"CDAH"))}]
     },
+    DetectConditions {
+        demux_name: "amf",
+        extensions: ".amf",
+        regex:      "",
+        conditions: &[]
+    },
     DetectConditions {
         demux_name: "ark-an",
         extensions: ".an",
@@ -330,6 +336,12 @@ const DETECTORS: &[DetectConditions] = &[
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"AN15")},
                       CheckItem{offs: 4, cond: &CC::Eq(Arg::U32LE(64))}]
     },
+    DetectConditions {
+        demux_name: "avenger",
+        extensions: ".bin",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0x1040, cond: &CC::Str(b"sarc20")}]
+    },
     DetectConditions {
         demux_name: "avf",
         extensions: ".avf",
@@ -374,12 +386,26 @@ const DETECTORS: &[DetectConditions] = &[
                       CheckItem{offs: 12, cond: &CC::Eq(Arg::U16LE(10))},
                       CheckItem{offs: 14, cond: &CC::Eq(Arg::U16LE(1))}]
     },
+    DetectConditions {
+        demux_name: "byon-m",
+        extensions: ".m",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"BYON PIZZA")}]
+    },
     DetectConditions {
         demux_name: "ca2",
         extensions: ".ca2",
         regex:      "",
         conditions: &[]
     },
+    DetectConditions {
+        demux_name: "ccommand",
+        extensions: ".bin",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0x7D0, cond: &CC::Eq(Arg::U32BE(0))},
+                      CheckItem{offs: 0xFD0, cond: &CC::Eq(Arg::U32BE(0))},
+                      CheckItem{offs: 0x4C40, cond: &CC::Eq(Arg::U32BE(0))},]
+    },
     DetectConditions {
         demux_name: "cda",
         extensions: ".cda",
@@ -387,6 +413,12 @@ const DETECTORS: &[DetectConditions] = &[
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"LSANM")},
                       CheckItem{offs: 6, cond: &CC::In(Arg::Byte(1), Arg::Byte(2))}]
     },
+    DetectConditions {
+        demux_name: "cfo",
+        extensions: ".cfo",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"CFO\0")} ]
+    },
     DetectConditions {
         demux_name: "ci2",
         extensions: ".ci2",
@@ -411,6 +443,14 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "ACT.CRH,END.CRH,GO.CRH,INT.CRH",
         conditions: &[]
     },
+    DetectConditions {
+        demux_name: "cup",
+        extensions: ".cup",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"BEAN")},
+                      CheckItem{offs: 8, cond: &CC::Str(b"HEAD")},
+                      CheckItem{offs: 22, cond: &CC::Str(b"RGBS")}]
+    },
     DetectConditions {
         demux_name: "cyclemania",
         extensions: ".hed",
@@ -463,6 +503,13 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[]
     },
+    DetectConditions {
+        demux_name: "egg",
+        extensions: ".egg",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"EGG\x00")},
+                      CheckItem{offs: 4, cond: &CC::Eq(Arg::U32BE(0x350))}]
+    },
     DetectConditions {
         demux_name: "etv",
         extensions: ".etv",
@@ -529,6 +576,35 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"FMV*")}]
     },
+    DetectConditions {
+        demux_name: "hnm0",
+        extensions: ".hnm",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Eq(Arg::U32BE(0xAA015556))}]
+    },
+    DetectConditions {
+        demux_name: "hnm1",
+        extensions: ".hnm",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::In(Arg::U16LE(0x6C), Arg::U16LE(0x4000))}]
+    },
+    DetectConditions {
+        demux_name: "hnm4",
+        extensions: ".hnm",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"HNM4")}]
+    },
+    DetectConditions {
+        demux_name: "imv",
+        extensions: ".imv",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Eq(Arg::U32LE(40))},
+                      CheckItem{offs: 4, cond: &CC::Eq(Arg::U32LE(0))},
+                      CheckItem{offs: 6, cond: &CC::Eq(Arg::U16LE(2))},
+                      CheckItem{offs: 40, cond: &CC::Eq(Arg::U32LE(28))},
+                      CheckItem{offs: 44, cond: &CC::Eq(Arg::U32LE(40))},
+                      CheckItem{offs: 46, cond: &CC::Eq(Arg::U16LE(1))}]
+    },
     DetectConditions {
         demux_name: "imx",
         extensions: ".imx",
@@ -586,18 +662,65 @@ const DETECTORS: &[DetectConditions] = &[
                       CheckItem{offs: 4, cond: &CC::Eq(Arg::U32LE(0x1C))},
                       CheckItem{offs: 0x1C, cond: &CC::Str(b"i42K")}]
     },
+    DetectConditions {
+        demux_name: "kingpin-bin",
+        extensions: "",
+        regex:      "movie\\d+.bin",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"Conf")},
+                      CheckItem{offs: 4, cond: &CC::Eq(Arg::U32BE(0x28))},
+                      CheckItem{offs: 0x28, cond: &CC::Str(b"AUDI")}]
+    },
+    DetectConditions {
+        demux_name: "kmvid",
+        extensions: ".vid",
+        regex:      "",
+        conditions: &[]
+    },
+    DetectConditions {
+        demux_name: "koda",
+        extensions: ".stm",
+        regex:      "",
+        conditions: &[]
+    },
     DetectConditions {
         demux_name: "lair",
         extensions: "",
         regex:      "A\\d\\d\\d\\d\\d.DAT",
         conditions: &[]
     },
+    DetectConditions {
+        demux_name: "lms",
+        extensions: ".lms",
+        regex:      "",
+        conditions: &[]
+    },
     DetectConditions {
         demux_name: "lotr-av",
         extensions: ".av",
         regex:      "",
         conditions: &[]
     },
+    DetectConditions {
+        demux_name: "m95",
+        extensions: ".m95",
+        regex:      "",
+        conditions: &[]
+    },
+    DetectConditions {
+        demux_name: "maelstrom-anm",
+        extensions: ".anm",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"ANIM")},
+                      CheckItem{offs: 8, cond: &CC::Str(b"BPIC")}]
+    },
+    DetectConditions {
+        demux_name: "mfilm",
+        extensions: ".film",
+        regex:      "",
+        conditions: &[CheckItem{offs:  0, cond: &CC::Str(b"LIST")},
+                      CheckItem{offs:  8, cond: &CC::Str(b"FILMPROP")},
+                      CheckItem{offs: 20, cond: &CC::Str(b"LIST")}]
+    },
     DetectConditions {
         demux_name: "mh-fmv",
         extensions: ".fmv",
@@ -610,6 +733,14 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[CheckItem{offs: 0, cond: &CC::Eq(Arg::U32LE(0xAA07))}]
     },
+    DetectConditions {
+        demux_name: "ninja-bin",
+        extensions: ".bin",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0x640, cond: &CC::Eq(Arg::U32BE(0))},
+                      CheckItem{offs: 0xE40, cond: &CC::Eq(Arg::U32BE(0))},
+                      CheckItem{offs: 0x4C40, cond: &CC::Eq(Arg::U32BE(0))},]
+    },
     DetectConditions {
         demux_name: "nl-fmv2",
         extensions: ".fmv2",
@@ -632,6 +763,14 @@ const DETECTORS: &[DetectConditions] = &[
                       CheckItem{offs: 8, cond: &CC::Or(&CC::Str(b"INTR"), &CC::Str(b"ENDG"))},
                       CheckItem{offs: 12, cond: &CC::Str(b"FLIC")}]
     },
+    DetectConditions {
+        demux_name: "origin-sc",
+        extensions: ".dat",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Eq(Arg::U16LE(0x105))},
+                      CheckItem{offs: 2, cond: &CC::Eq(Arg::U16LE(320))},
+                      CheckItem{offs: 4, cond: &CC::Eq(Arg::U16LE(200))}]
+    },
     DetectConditions {
         demux_name: "origin-ssm",
         extensions: ".movie",
@@ -706,6 +845,12 @@ const DETECTORS: &[DetectConditions] = &[
                       CheckItem{offs: 2, cond: &CC::Str(b"SOL\0")},
                       CheckItem{offs: 6, cond: &CC::In(Arg::U16LE(4), Arg::U16LE(6))}],
     },
+    DetectConditions {
+        demux_name: "reaper-fmv",
+        extensions: ".fmv",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"!Reaper!") }],
+    },
     DetectConditions {
         demux_name: "rlf",
         extensions: ".rlf",
@@ -724,12 +869,20 @@ const DETECTORS: &[DetectConditions] = &[
         extensions: ".vb,.vbc,.fcp,.son",
         regex:      "",
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"SIFF")},
-                      CheckItem{offs: 4, cond: &CC::Or(
+                      CheckItem{offs: 8, cond: &CC::Or(
                                     &CC::Or(
                                         &CC::Str(b"VBV1VBHD"),
                                         &CC::Str(b"SOUNSHDR")),
                                     &CC::Str(b"FCPKFCHD"))}],
     },
+    DetectConditions {
+        demux_name: "smv",
+        extensions: ".smv",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"ST")},
+                      CheckItem{offs: 8, cond: &CC::Eq(Arg::U16LE(16))},
+                      CheckItem{offs: 16, cond: &CC::Eq(Arg::U16LE(16))}]
+    },
     DetectConditions {
         demux_name: "soulhunt",
         extensions: ".vid",
@@ -737,6 +890,13 @@ const DETECTORS: &[DetectConditions] = &[
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"DV")},
                       CheckItem{offs: 2, cond: &CC::Eq(Arg::U16LE(0))}]
     },
+    DetectConditions {
+        demux_name: "spidy-ani",
+        extensions: ".ani",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"SpidyAni2")},
+                      CheckItem{offs: 19, cond: &CC::Str(b"Pal ")}]
+    },
     DetectConditions {
         demux_name: "talisman",
         extensions: ".ani",
@@ -756,6 +916,12 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"Artform\0") }]
     },
+    DetectConditions {
+        demux_name: "vdx",
+        extensions: ".vdx,.gjd",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Eq(Arg::U16BE(0x6792)) }],
+    },
     DetectConditions {
         demux_name: "vpx1",
         extensions: ".vpx",
@@ -768,6 +934,21 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"VXDS") }],
     },
+    DetectConditions {
+        demux_name: "warrior-anm", // release version
+        extensions: ".anm",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"CHCK") },
+                      CheckItem{offs: 4, cond: &CC::Eq(Arg::U32BE(0x00010300)) }],
+    },
+    DetectConditions {
+        demux_name: "warrior-anm", // demo
+        extensions: ".anm",
+        regex:      "",
+        conditions: &[CheckItem{offs: 0, cond: &CC::Eq(Arg::U32BE(0x00010300)) },
+                      CheckItem{offs: 4, cond: &CC::Or(&CC::Eq(Arg::U16LE(320)), &CC::Eq(Arg::U16LE(640))) },
+                      CheckItem{offs: 6, cond: &CC::Or(&CC::Eq(Arg::U16LE(240)), &CC::Eq(Arg::U16LE(480))) }],
+    },
     DetectConditions {
         demux_name: "wingnuts",
         extensions: ".dat",
@@ -788,6 +969,12 @@ const DETECTORS: &[DetectConditions] = &[
         regex:      "",
         conditions: &[CheckItem{offs: 0, cond: &CC::Str(b"Archivo MXV.\x1A") }],
     },
+    DetectConditions {
+        demux_name: "yqs",
+        extensions: ".yqs",
+        regex:      "",
+        conditions: &[],
+    },
     DetectConditions {
         demux_name: "yumimi-ablk",
         extensions: ".abk,.dat",
