@@ -6,6 +6,7 @@ use crate::input::util::rnc::rnc_uncompress;
 
 #[derive(Debug,PartialEq)]
 enum FlicType {
+    CFO,
     FLI,
     FLC,
     FLH,
@@ -459,7 +460,9 @@ impl InputSource for FlicDecoder {
             let chunk_size = br.read_u32le()?;
             let chunk_type = br.read_u16le()?;
             //println!("chunk {chunk_type:X} size {chunk_size:X} @ {:X}", br.tell() - 6);
-            let (chunk_size, pal_flag) = if self.subtype != FlicType::PTF {
+            let (chunk_size, pal_flag) = if self.subtype == FlicType::CFO {
+                    (chunk_size as usize + 2, false)
+                } else if self.subtype != FlicType::PTF {
                     validate!(chunk_size >= 6);
                     (chunk_size as usize - 6, false)
                 } else if (chunk_size & 0x80000000) == 0 {
@@ -480,7 +483,7 @@ impl InputSource for FlicDecoder {
                 }
             }
             match self.subtype {
-                FlicType::FLI | FlicType::FLC | FlicType::MagicCarpet | FlicType::Origin => {
+                FlicType::FLI | FlicType::FLC | FlicType::MagicCarpet | FlicType::Origin | FlicType::CFO => {
                     validate!(chunk_type >= 0xF100);
                 },
                 FlicType::PTF => {},
@@ -525,13 +528,15 @@ impl InputSource for FlicDecoder {
                 0xF1FA => {
                     let chunks = br.read_u16le()? as usize;
                     validate!(chunks * 6 <= chunk_size);
-                    let _delay = br.read_u16le()?;
-                    let _zero  = br.read_u16le()?;
-                    let cur_w  = br.read_u16le()? as usize;
-                    let cur_h  = br.read_u16le()? as usize;
-                    validate!(cur_w <= self.video.width && cur_h <= self.video.height);
-                    self.video.cur_w = if cur_w > 0 { cur_w } else { self.video.width };
-                    self.video.cur_h = if cur_h > 0 { cur_h } else { self.video.height };
+                    if self.subtype != FlicType::CFO {
+                        let _delay = br.read_u16le()?;
+                        let _zero  = br.read_u16le()?;
+                        let cur_w  = br.read_u16le()? as usize;
+                        let cur_h  = br.read_u16le()? as usize;
+                        validate!(cur_w <= self.video.width && cur_h <= self.video.height);
+                        self.video.cur_w = if cur_w > 0 { cur_w } else { self.video.width };
+                        self.video.cur_h = if cur_h > 0 { cur_h } else { self.video.height };
+                    }
 
                     if chunk_size == 11 && self.subtype == FlicType::PTF {
                         br.read_skip(1)?;
@@ -547,7 +552,7 @@ impl InputSource for FlicDecoder {
                         }
                         match self.subtype {
                             FlicType::FLI | FlicType::FLC | FlicType::MagicCarpet |
-                            FlicType::Origin | FlicType::PTF => {
+                            FlicType::Origin | FlicType::PTF | FlicType::CFO => {
                                 validate!(subchunk_type < 100);
                             },
                             FlicType::FLH => {
@@ -610,6 +615,9 @@ impl InputSource for FlicDecoder {
                 },
                 0xF1FB => return Err(DecoderError::NotImplemented), // segment table
                 0xF1FC => return Err(DecoderError::NotImplemented), // Huffman table
+                0xFAF1 if self.subtype == FlicType::CFO => {
+                    br.read_skip(chunk_size)?;
+                },
                 _ => {
                     println!(" skipping unknown chunk {chunk_type:04X} @ {:X}", br.tell() - 6);
                     br.read_skip(chunk_size)?;
@@ -620,6 +628,52 @@ impl InputSource for FlicDecoder {
     }
 }
 
+pub fn open_cfo(name: &str) -> DecoderResult<Box<dyn InputSource>> {
+    let file = File::open(name).map_err(|_| DecoderError::InputNotFound(name.to_owned()))?;
+    let mut fr = FileReader::new_read(BufReader::new(file));
+    let mut br = ByteReader::new(&mut fr);
+
+    let tag         = br.read_tag()?;
+    validate!(&tag == b"CFO\0");
+    let _zero       = br.read_u32le()?;
+    let nframes     = br.read_u16le()?;
+    let width       = br.read_u16le()? as usize;
+    let height      = br.read_u16le()? as usize;
+    validate!(width > 0 && width <= 2048 && height > 0 && height <= 1536);
+    let mut speed   = br.read_u32le()?;
+    validate!(speed < 1000);
+    if speed == 0 {
+        speed = 10;
+    }
+    let offset      = br.read_u32le()?;
+    validate!(offset >= 22);
+    br.seek(SeekFrom::Start(u64::from(offset)))?;
+
+    Ok(Box::new(FlicDecoder {
+        fr,
+        frm_no: 0,
+        nframes,
+        speed,
+        fli_end: u64::from(std::u32::MAX),
+        tot_size: u64::from(std::u32::MAX),
+        subtype: FlicType::CFO,
+        audio16: Vec::new(),
+        firstaud: false,
+        aligned: false,
+        video: VideoData {
+            width, height,
+            depth: 8,
+            cur_w: width,
+            cur_h: height,
+            pal: [0; 768],
+            frame: vec![0; width * height],
+            frame16: Vec::new(),
+            unp_buf: Vec::new(),
+            vdata: Vec::new(),
+        },
+    }))
+}
+
 pub fn open_fli(name: &str) -> DecoderResult<Box<dyn InputSource>> {
     let file = File::open(name).map_err(|_| DecoderError::InputNotFound(name.to_owned()))?;
     let mut fr = FileReader::new_read(BufReader::new(file));
