@@ -8,6 +8,7 @@ const TICK_DIVISOR: u32 = 5;
 
 struct NXLDecoder {
     fr:         FileReader<File>,
+    flavour:    u8,
     pal:        [u8; 768],
     frame:      Vec<u8>,
     tmp_pic:    Vec<u8>,
@@ -135,7 +136,19 @@ impl InputSource for NXLDecoder {
 
                     validate!(time >= self.vpts);
 
-                    br.read_vga_pal_some(&mut self.pal[..pal_size])?;
+                    let is_mac_nxl2 = self.depth == 8 && self.flavour == 0x14;
+
+                    if !is_mac_nxl2 {
+                        br.read_vga_pal_some(&mut self.pal[..pal_size])?;
+                    } else {
+                        for clr in self.pal[..pal_size].chunks_exact_mut(3) {
+                            let b = br.read_u16le()?;
+                            clr[2] = (b >> 10 << 3) as u8;
+                            clr[1] = (b >>  5 << 3) as u8;
+                            clr[0] = (b       << 3) as u8;
+                        }
+                    }
+
                     if width > 0 {
                         self.tmp_pic.clear();
                         self.tmp_pic.resize(width * height, 0);
@@ -153,8 +166,16 @@ impl InputSource for NXLDecoder {
                             for dline in self.tmp_pic.chunks_exact_mut(width) {
                                 br.read_buf(dline)?;
                             }
-                            blit_frame_vga(&mut self.frame[x_off + y_off * self.width..], self.width,
-                                           &self.tmp_pic, width, scaling);
+                            if !is_mac_nxl2 {
+                                blit_frame_vga(&mut self.frame[x_off + y_off * self.width..], self.width,
+                                               &self.tmp_pic, width, scaling);
+                            } else {
+                                // skip leftover after palette
+                                br.read_skip(256)?;
+                                blit_frame_ega(&mut self.frame[x_off + y_off * self.width..], self.width,
+                                               &self.tmp_pic, width, scaling);
+
+                            }
                         }
                     }
                     br.read_skip(size - 64 - pal_size - vsize)?;
@@ -301,7 +322,8 @@ pub fn open(name: &str) -> DecoderResult<Box<dyn InputSource>> {
 
     let b = br.read_byte()?;
     validate!(b == 1);
-    br.read_skip(3)?;
+    let flavour = br.read_byte()?;
+    br.read_skip(2)?;
     let size = br.read_u32be()?;
     validate!(size == 64);
     let chunk_no = br.read_u32be()?;
@@ -322,6 +344,7 @@ pub fn open(name: &str) -> DecoderResult<Box<dyn InputSource>> {
 
     Ok(Box::new(NXLDecoder {
         fr,
+        flavour,
         width, height, depth,
         arate,
         pal:     [0; 768],
