@@ -410,18 +410,18 @@ impl<S: Copy> CodebookDescReader<S> for Vec<FullCodebookDesc<S>> {
 }
 
 /// Codebook description that stores a list of codewords and their value is equal to the index.
-pub struct ShortCodebookDescReader {
-    data: Vec<ShortCodebookDesc>,
+pub struct ShortCodebookDescReader<'a> {
+    data: &'a [ShortCodebookDesc],
 }
 
-impl ShortCodebookDescReader {
+impl<'a> ShortCodebookDescReader<'a> {
     /// Constructs a new `ShortCodebookDescReader` instance.
-    pub fn new(data: Vec<ShortCodebookDesc<>>) -> Self {
+    pub fn new(data: &'a [ShortCodebookDesc]) -> Self {
         ShortCodebookDescReader { data }
     }
 }
 
-impl CodebookDescReader<u32> for ShortCodebookDescReader {
+impl<'a> CodebookDescReader<u32> for ShortCodebookDescReader<'a> {
     fn bits(&mut self, idx: usize) -> u8  { self.data[idx].bits }
     fn code(&mut self, idx: usize) -> u32 { self.data[idx].code }
     fn sym (&mut self, idx: usize) -> u32 { idx as u32 }
