@@ -4,7 +4,7 @@ use std::io::BufWriter;
 use crate::io::byteio::*;
 use super::*;
 
-const MAX_RIFF_BLOCKS: usize = 4; // ~4GB file should be enough for game videos
+const MAX_RIFF_BLOCKS: usize = 16; // ~4^H16GB file should be enough for game videos
 const MAX_RIFF_SIZE: u64 = 900 << 20; // 900MB of payload plus index data will hopefully fit in 1GB chunk limit
 
 #[cfg(debug_assertions)]
@@ -128,9 +128,8 @@ impl AVIWriter {
         self.blk_start = bw.tell();
         self.wrote_hdr = false;
 
-        if self.riff_blk == 1 {
-            self.patch_stream_stats()?;
-        }
+        // keep updating actual stream statistics and flags
+        self.patch_stream_stats()?;
 
         Ok(())
     }
